#!/bin/bash

restoreLog=$(mktemp /dev/shm/restoreLog-XXXXXXXXX.txt)

echoLog () {
    echo $(date +"[%H:%M:%S.%2N]") $1 | tee -a $restoreLog
}

echoLog "Restoring previous TaskForce firmware version."
if [ -z $1 ]; then
    echoLog "No backup directory specified. Exiting."
    exit 1
fi

backupDir=$1
echoLog $backupDir

if [ -f $backupDir/pre-restore.sh ]; then
    echoLog "Executing pre-restore script."
    bash $backupDir/pre-restore.sh | tee -a $restoreLog
fi

echoLog "Remouting read-write."
mount -no remount,rw /
mount -no remount,rw /home
mount -no remount,rw /boot

echoLog "Backing up existing firmware."
rm -rf /home/atola/server.restore
mkdir /home/atola/server.restore
mv /home/atola/server/* /home/atola/server.restore

echoLog "Copying new files."
yes | cp -r $backupDir/* /home/atola/server

echoLog "Remounting read-only"
mount -no remount,ro /boot  | tee -a $restoreLog
mount -no remount,ro /home  | tee -a $restoreLog
mount -no remount,ro /  | tee -a $restoreLog

if [ -f $backupDir/post-restore.sh ]; then
    echoLog "Executing post-restore script."
    bash $backupDir/post-restore.sh | tee -a $restoreLog
fi

echoLog "Starting TaskForce..."
bash /home/atola/server/launch.sh | tee -a $restoreLog
