#!/bin/bash

updateLog=$(mktemp /dev/shm/updateLog-XXXXXXXXX.txt)

echoLog () {
    echo $(date +"[%H:%M:%S.%2N]") $1 | tee -a $updateLog
}

echoLog "Updating TaskForce."
if [ -z $1 ]; then
    echoLog "No firmware file specified. Exiting."
    exit 1
fi

tempDir=$(mktemp -d /dev/shm/firmware-XXXXXXXXX)
echoLog "Unpacking firmware to $tempDir."
unzip $1 -d $tempDir

if [ -f $tempDir/home/atola/server/pre-update.sh ]; then
    echoLog "Executing pre-update script."
    bash $tempDir/home/atola/server/pre-update.sh | tee -a $updateLog
fi

echoLog "Remouting read-write."
mount -no remount,rw /
mount -no remount,rw /home
mount -no remount,rw /boot

echoLog "Backing up existing firmware."
rm -rf /home/atola/server.backup
mkdir /home/atola/server.backup
mv /home/atola/server/* /home/atola/server.backup

echoLog "Copying new files."
yes | cp -r $tempDir/* /

echoLog "Remounting read-only"
mount -no remount,ro /boot
mount -no remount,ro /home
mount -no remount,ro /

if [ -f $tempDir/home/atola/server/post-update.sh ]; then
    echoLog "Executing post-update script."
    bash $tempDir/home/atola/server/post-update.sh | tee -a $updateLog
fi

echoLog "Successfully updated. Removing temporary directory."
rm -rf $tempDir

echoLog "Starting TaskForce..."
bash /home/atola/server/launch.sh
